/**********************************************************************************************************

This program file generates the ciritical values of the QLR test in Baek, Cho, and Phillips (2013).
The researcher can choose the following six values to obtain the critical values:

    1) lb:    lower bound of the parameter space;
    2) ub:    upper bound of the parameter space;
    3) grd:   grid distance of the parameter between two parameter values;
    4) lll:   number of the standard normal coefficients; 
    5) niter: number of iterations; and
    6) lvl:   level of significance of the QLR test.

In order to implement this program, the following steps are required:

    Step 1: save the following three procedures in the same directory as the current program file is located; 
            1) agam.prc
            2) gsqr.prc;
            3) nulldist.prc.
    Step 2: choose the above 5 option values;
    Step 3: run this program and wait until the running is over; and
    Step 4: Choose your level of significance and obtain the asymptotic critical values.

06/01/2013
Jin Seo CHO
**********************************************************************************************************/
new;
library pgraph;
prcsn 64;
#include agam.prc;
#include gsqr.prc;
#include nulldist.prc;

lb    = 0.1;           // lower bound of Gamma space
ub    = 1.5;           // upper bound of Gamma space
niter = 1000;          // number of iterations
lll   = 100;           // number of standard normal coefficients;
grd   = 0.01;          // grid distance 

lv1   = 0.01;          // 1% level of significance;
lv5   = 0.05;          // 5% level of significance;
lv10  = 0.10;          // 10% level of significance; 

www = nulldist(lb,ub,niter,lll,grd);

print "============================================================";
print "critical value at the level of significanc =" lv1;
print "                                            " www[round((1-lv1)*niter),3];
print "============================================================";
print "critical value at the level of significanc =" lv5;
print "                                            " www[round((1-lv5)*niter),3];
print "============================================================";
print "critical value at the level of significanc =" lv10;
print "                                            " www[round((1-lv10)*niter),3];
print "============================================================";
